@@ -1,26 +1,12 @@
 package Net::Google::Code::Role;
 use Moose::Role;
-use Params::Validate;
 
 with 'Net::Google::Code::Role::Fetchable';
 with 'Net::Google::Code::Role::URL';
-
-has 'project' => (
-    isa      => 'Str',
-    reader   => '_project',
-    required => 1,
-);
-
-=head2 project
-
-# TODO Role's 'requires' can't work with attributes yet
-# waiting for Moose's update
-
-=cut
-
-sub project { return shift->_project }
-
-
+with 'Net::Google::Code::Role::HTMLTree';
+with 'Net::Google::Code::Role::Authentication';
+with 'Net::Google::Code::Role::DateTime';
+with 'Net::Google::Code::Role::Pageable';
 
 no Moose::Role;
 
@@ -30,18 +16,16 @@ __END__
 
 =head1 NAME
 
-Net::Google::Code::Role - 
-
+Net::Google::Code::Role - Role
 
 =head1 DESCRIPTION
 
-=head1 INTERFACE
+this is an aggregation role that includes all the roles.
 
 =head1 AUTHOR
 
 sunnavy  C<< <sunnavy@bestpractical.com> >>
 
-
 =head1 LICENCE AND COPYRIGHT
 
 Copyright 2008-2009 Best Practical Solutions.
@@ -49,3 +33,4 @@ Copyright 2008-2009 Best Practical Solutions.
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
 
+
